from setuptools import setup 
  
setup( 
    name='unimore_cicd', 
    version='0.1', 
    description='A sample Python package to test CI/CD', 
    long_description='A sample Python package to test CI/CD',
    author='Angelo Ferrando', 
    author_email='angelo.ferrando42@gmail.com', 
    packages=['my_math'], 
    install_requires=['pytest'], 
) 